{ config, lib, pkgs, ... }:

{
  imports = [
    ./accounts.secret.nix

    ../modules/window_manager
    ../modules/terminal.nix
    ../modules/shell.nix

    ../modules/notifications
    ../modules/file_manager
    ../modules/mail
    ../modules/ledger.nix
    ../modules/pass.nix

    ../modules/git.nix
    ../modules/dev_tools.nix
    ../modules/editor.nix

    ../modules/work_tools.nix
  ];

  xdg.enable = true;

  home.keyboard = {
    model = "pc105";
    layout = "us,ru";
    variant = "dvorak,";
    options = [ "grp:win_space_toggle" ];
  };

  home.packages = with pkgs; [
    kotatogram-desktop
    nheko
    libreoffice
    image-roll

    asciinema # record the terminal
    neofetch # command-line system information

    # browser
    # a fork of firefox, focused on privacy, security and freedom
    (librewolf.override {
      extraNativeMessagingHosts = [ passff-host ];
    })
  ];

  local.git = {
    gpgKey = "7685890DCD544AF1507A84F21B59187B161C0215";
    userEmail = "dmitriy@ideascup.me";
    userName = "Dmitriy Pleshevskiy";
    git-crypt.enable = true;
  };

  programs.zsh.initExtra = lib.mkAfter ''
    eval "$(cat $HOME/repos/tas/shell/zsh)"
    eval $(kubectl completion zsh)
  '';

  home.file = {
    "scripts" = {
      source = ./scripts;
      recursive = true;
    };

    "pictures/wallpapers" = {
      source = ./wallpapers;
      recursive = true;
    };
  };

}
